@@ -1,20 +1,21 @@
 # -*- perl -*-
+
 #
 # Author: Gisbert W. Selke, TapirSoft Selke & Selke GbR.
 #
-# Copyright (C) 2015, 2025 Gisbert W. Selke. All rights reserved.
+# Copyright (C) 2015 Gisbert W. Selke. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
 # Mail: gws@cpan.org
 #
+
+
 package Map::Tube::Glasgow;
-use 5.14.0;
-use version 0.77 ( );
 use strict;
 use warnings;
 
-our $VERSION = version->declare('v0.72.3');
+our $VERSION = '0.01';
 
 =encoding utf8
 
@@ -51,17 +52,10 @@ stations in Glasgow. All interesting methods are provided by the role L<Map::Tub
 =head2 CONSTRUCTOR
 
     use Map::Tube::Glasgow;
-    my $tube = Map::Tube::Glasgow->new();
+    my $tube = Map::Tube::Glasgow->new;
 
-The only argument, C<xml>, is optional; if specified, it should be a code ref
-to a function that returns either the path the XML map file, or a string
-containing this XML content. The default is the path to F<glasgow-map.xml>
-that is a part of this distribution. For further information see L<Map::Tube>.
-
-=head2 xml()
-
-This read-only accessor returns whatever was specified as the XML source at
-construction.
+This will read the tube information from the shared file F<glasgow-map.xml>,
+which is part of the distribution.
 
 =head1 ERRORS
 
